"""
    Store all Oy API URL PATH here
    ______________________________
"""
URLS = {
    "INQUIRY_ACCOUNT": "/api/inquiry",
    "DISBURSE": "/api/remit",
    "DISBURSE_STATUS": "/api/remit-status",
    "GET_BALANCE": "/api/balance",
    "GENERATE_VA": "/api/generate-static-va",
    "VA_INFO": "/api/static-virtual-account/",
    "VA_TRANSACTIONS": "/api/va-tx-history/",
}
